[![PyPI version](https://badge.fury.io/py/trodesnetwork.svg)](https://badge.fury.io/py/trodesnetwork)

# trodesnetwork

TrodesNetwork Python SDK is used to receive network signals from Trodes in realtime.

This is a package for accessing streaming Trodes data for real-time analysis
in Python.

## Documentation

Please see the documentation at <https://docs.spikegadgets.com/en/latest/advanced/NetworkingAPI.html>.